/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global define*/

/**
 * Dom helper module.
 * @namespace ArchiveManager/helpers/dom
 * @memberof ArchiveManager/helpers
 */
define({
    name: 'helpers/dom',
    requires: [
    ],
    def: function helpersDom() {
        'use strict';

        /**
         * Returns parent node of the child given as parameter.
         * @memberof ArchiveManager/helpers/dom
         * @param {HTMLElement} element
         * @param {string} parentTag
         * @return {HTMLElement}
         */
        function findParent(element, parentTag) {
            parentTag = parentTag.toLowerCase();

            do {
                if (element.tagName.toLowerCase() === parentTag) {
                    return element;
                }
                element = element.parentNode;
            } while (element.parentNode && element.parentNode.tagName);

            return null;
        }

        return {
            findParent: findParent
        };
    }
});
